# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class DataAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def publish_data(self, publish_data_list_dto, **kwargs):  # noqa: E501
        """publishData  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.publish_data(publish_data_list_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListOfParticipatorySensingDataAPIModel publish_data_list_dto: publishDataListDTO (required)
        :return: ListOfParticipatorySensingDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.publish_data_with_http_info(publish_data_list_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.publish_data_with_http_info(publish_data_list_dto, **kwargs)  # noqa: E501
            return data

    def publish_data_with_http_info(self, publish_data_list_dto, **kwargs):  # noqa: E501
        """publishData  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.publish_data_with_http_info(publish_data_list_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListOfParticipatorySensingDataAPIModel publish_data_list_dto: publishDataListDTO (required)
        :return: ListOfParticipatorySensingDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['publish_data_list_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method publish_data" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'publish_data_list_dto' is set
        if ('publish_data_list_dto' not in params or
                params['publish_data_list_dto'] is None):
            raise ValueError("Missing the required parameter `publish_data_list_dto` when calling `publish_data`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'publish_data_list_dto' in params:
            body_params = params['publish_data_list_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/data/publish', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListOfParticipatorySensingDataAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_summary(self, query_resource_data_criteria_dto, **kwargs):  # noqa: E501
        """queryLatestSummaryForResources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_summary(query_resource_data_criteria_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourceQueryCriteriaRequestAPIModel query_resource_data_criteria_dto: queryResourceDataCriteriaDTO (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_summary_with_http_info(query_resource_data_criteria_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_summary_with_http_info(query_resource_data_criteria_dto, **kwargs)  # noqa: E501
            return data

    def query_summary_with_http_info(self, query_resource_data_criteria_dto, **kwargs):  # noqa: E501
        """queryLatestSummaryForResources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_summary_with_http_info(query_resource_data_criteria_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourceQueryCriteriaRequestAPIModel query_resource_data_criteria_dto: queryResourceDataCriteriaDTO (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_resource_data_criteria_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_summary" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_resource_data_criteria_dto' is set
        if ('query_resource_data_criteria_dto' not in params or
                params['query_resource_data_criteria_dto'] is None):
            raise ValueError("Missing the required parameter `query_resource_data_criteria_dto` when calling `query_summary`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_resource_data_criteria_dto' in params:
            body_params = params['query_resource_data_criteria_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/summary', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TheResourceSummaryDataAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_latest(self, query_latest_resource_data_dto, **kwargs):  # noqa: E501
        """queryLatestValuesForResources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_latest(query_latest_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CollectionOfDataQueryCriteriaRequestAPIModel query_latest_resource_data_dto: queryLatestResourceDataDTO (required)
        :return: ResourceLatestDataResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_latest_with_http_info(query_latest_resource_data_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_latest_with_http_info(query_latest_resource_data_dto, **kwargs)  # noqa: E501
            return data

    def query_latest_with_http_info(self, query_latest_resource_data_dto, **kwargs):  # noqa: E501
        """queryLatestValuesForResources  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_latest_with_http_info(query_latest_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CollectionOfDataQueryCriteriaRequestAPIModel query_latest_resource_data_dto: queryLatestResourceDataDTO (required)
        :return: ResourceLatestDataResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_latest_resource_data_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_latest" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_latest_resource_data_dto' is set
        if ('query_latest_resource_data_dto' not in params or
                params['query_latest_resource_data_dto'] is None):
            raise ValueError("Missing the required parameter `query_latest_resource_data_dto` when calling `query_latest_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_latest_resource_data_dto' in params:
            body_params = params['query_latest_resource_data_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/latest', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceLatestDataResponseAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_time_range(self, query_time_range_resource_data_dto, **kwargs):  # noqa: E501
        """queryTimeRange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_time_range(query_time_range_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListOfQueryCriteriaWithinATimeframeRequestAPIModel query_time_range_resource_data_dto: queryTimeRangeResourceDataDTO (required)
        :return: ResourceQueryCriteriaWithinATimeframeResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_time_range_with_http_info(query_time_range_resource_data_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_time_range_with_http_info(query_time_range_resource_data_dto, **kwargs)  # noqa: E501
            return data

    def query_time_range_with_http_info(self, query_time_range_resource_data_dto, **kwargs):  # noqa: E501
        """queryTimeRange  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_time_range_with_http_info(query_time_range_resource_data_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ListOfQueryCriteriaWithinATimeframeRequestAPIModel query_time_range_resource_data_dto: queryTimeRangeResourceDataDTO (required)
        :return: ResourceQueryCriteriaWithinATimeframeResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query_time_range_resource_data_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_time_range" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query_time_range_resource_data_dto' is set
        if ('query_time_range_resource_data_dto' not in params or
                params['query_time_range_resource_data_dto'] is None):
            raise ValueError("Missing the required parameter `query_time_range_resource_data_dto` when calling `query_time_range`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query_time_range_resource_data_dto' in params:
            body_params = params['query_time_range_resource_data_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query/timerange', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceQueryCriteriaWithinATimeframeResponseAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_summary(self, uuid, **kwargs):  # noqa: E501
        """retrieveLatestSummary  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_summary(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: uuid (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_summary_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_summary_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def retrieve_summary_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """retrieveLatestSummary  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_summary_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: uuid (required)
        :return: TheResourceSummaryDataAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_summary" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `retrieve_summary`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}/summary', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TheResourceSummaryDataAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_latest(self, uuid, **kwargs):  # noqa: E501
        """retrieveLatestValues  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_latest(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: uuid (required)
        :return: ResourceLatestValuesResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_latest_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_latest_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def retrieve_latest_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """retrieveLatestValues  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_latest_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: uuid (required)
        :return: ResourceLatestValuesResponseAPIModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_latest" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `retrieve_latest_values`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}/latest', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceLatestValuesResponseAPIModel',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.phenomenon_api_api import PhenomenonAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestPhenomenonAPIApi(unittest.TestCase):
    """PhenomenonAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.phenomenon_api_api.PhenomenonAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_phenomenon(self):
        """Test case for create_phenomenon

        Create a Phenomenon  # noqa: E501
        """
        pass

    def test_delete_phenomenon(self):
        """Test case for delete_phenomenon

        Delete a Phenomenon by its UUID  # noqa: E501
        """
        pass

    def test_get_phenomenon_by_u_uid(self):
        """Test case for get_phenomenon_by_u_uid

        Retrieve a Phenomenon by its UUID  # noqa: E501
        """
        pass

    def test_list_all_phenomenons(self):
        """Test case for list_all_phenomenons

        Retrieve a collection of Phenomenons  # noqa: E501
        """
        pass

    def test_query_phenomenons(self):
        """Test case for query_phenomenons

        Retrieve a Phenomenon by a query  # noqa: E501
        """
        pass

    def test_update_phenomenon(self):
        """Test case for update_phenomenon

        Update Phenomenon  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceUpdateDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'controls': 'str',
        'phenomenon_uuid': 'str',
        'type': 'str',
        'unit_uuid': 'str',
        'user_friendly_name': 'str'
    }

    attribute_map = {
        'controls': 'controls',
        'phenomenon_uuid': 'phenomenonUuid',
        'type': 'type',
        'unit_uuid': 'unitUuid',
        'user_friendly_name': 'userFriendlyName'
    }

    def __init__(self, controls=None, phenomenon_uuid=None, type=None, unit_uuid=None, user_friendly_name=None):  # noqa: E501
        """ResourceUpdateDTO - a model defined in Swagger"""  # noqa: E501

        self._controls = None
        self._phenomenon_uuid = None
        self._type = None
        self._unit_uuid = None
        self._user_friendly_name = None
        self.discriminator = None

        if controls is not None:
            self.controls = controls
        if phenomenon_uuid is not None:
            self.phenomenon_uuid = phenomenon_uuid
        if type is not None:
            self.type = type
        if unit_uuid is not None:
            self.unit_uuid = unit_uuid
        if user_friendly_name is not None:
            self.user_friendly_name = user_friendly_name

    @property
    def controls(self):
        """Gets the controls of this ResourceUpdateDTO.  # noqa: E501


        :return: The controls of this ResourceUpdateDTO.  # noqa: E501
        :rtype: str
        """
        return self._controls

    @controls.setter
    def controls(self, controls):
        """Sets the controls of this ResourceUpdateDTO.


        :param controls: The controls of this ResourceUpdateDTO.  # noqa: E501
        :type: str
        """

        self._controls = controls

    @property
    def phenomenon_uuid(self):
        """Gets the phenomenon_uuid of this ResourceUpdateDTO.  # noqa: E501


        :return: The phenomenon_uuid of this ResourceUpdateDTO.  # noqa: E501
        :rtype: str
        """
        return self._phenomenon_uuid

    @phenomenon_uuid.setter
    def phenomenon_uuid(self, phenomenon_uuid):
        """Sets the phenomenon_uuid of this ResourceUpdateDTO.


        :param phenomenon_uuid: The phenomenon_uuid of this ResourceUpdateDTO.  # noqa: E501
        :type: str
        """

        self._phenomenon_uuid = phenomenon_uuid

    @property
    def type(self):
        """Gets the type of this ResourceUpdateDTO.  # noqa: E501


        :return: The type of this ResourceUpdateDTO.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResourceUpdateDTO.


        :param type: The type of this ResourceUpdateDTO.  # noqa: E501
        :type: str
        """
        allowed_values = ["Actuator", "Sensor", "Undefined"]  # noqa: E501
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def unit_uuid(self):
        """Gets the unit_uuid of this ResourceUpdateDTO.  # noqa: E501


        :return: The unit_uuid of this ResourceUpdateDTO.  # noqa: E501
        :rtype: str
        """
        return self._unit_uuid

    @unit_uuid.setter
    def unit_uuid(self, unit_uuid):
        """Sets the unit_uuid of this ResourceUpdateDTO.


        :param unit_uuid: The unit_uuid of this ResourceUpdateDTO.  # noqa: E501
        :type: str
        """

        self._unit_uuid = unit_uuid

    @property
    def user_friendly_name(self):
        """Gets the user_friendly_name of this ResourceUpdateDTO.  # noqa: E501


        :return: The user_friendly_name of this ResourceUpdateDTO.  # noqa: E501
        :rtype: str
        """
        return self._user_friendly_name

    @user_friendly_name.setter
    def user_friendly_name(self, user_friendly_name):
        """Sets the user_friendly_name of this ResourceUpdateDTO.


        :param user_friendly_name: The user_friendly_name of this ResourceUpdateDTO.  # noqa: E501
        :type: str
        """

        self._user_friendly_name = user_friendly_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceUpdateDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceUpdateDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from sparkworks_client.api.command_api_api import CommandAPIApi
from sparkworks_client.api.data_api_api import DataAPIApi
from sparkworks_client.api.gateway_api_api import GatewayAPIApi
from sparkworks_client.api.group_api_api import GroupAPIApi
from sparkworks_client.api.participatory_sensing_api_api import ParticipatorySensingAPIApi
from sparkworks_client.api.phenomenon_api_api import PhenomenonAPIApi
from sparkworks_client.api.registry_api_api import RegistryAPIApi
from sparkworks_client.api.resource_api_api import ResourceAPIApi
from sparkworks_client.api.unit_api_api import UnitAPIApi



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "sparkworksrest"
VERSION = "1.0.1"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23",
    "requests"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="A client library for the sparkworks rest api",
    author_email="info@sparkworks.net",
    url="",
    keywords=["Swagger", "SparkWorks Core API"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    A client library for the sparkworks rest api
    """
)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ResourceQueryCriteriaRequestWithinATimeframeAPIModel(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_from': 'int',
        'granularity': 'str',
        'resource_uri': 'str',
        'resource_uuid': 'str',
        'result_limit': 'int',
        'target_uom': 'str',
        'to': 'int'
    }

    attribute_map = {
        '_from': 'from',
        'granularity': 'granularity',
        'resource_uri': 'resourceURI',
        'resource_uuid': 'resourceUuid',
        'result_limit': 'resultLimit',
        'target_uom': 'targetUom',
        'to': 'to'
    }

    def __init__(self, _from=None, granularity=None, resource_uri=None, resource_uuid=None, result_limit=None, target_uom=None, to=None):  # noqa: E501
        """ResourceQueryCriteriaRequestWithinATimeframeAPIModel - a model defined in Swagger"""  # noqa: E501

        self.__from = None
        self._granularity = None
        self._resource_uri = None
        self._resource_uuid = None
        self._result_limit = None
        self._target_uom = None
        self._to = None
        self.discriminator = None

        self._from = _from
        self.granularity = granularity
        if resource_uri is not None:
            self.resource_uri = resource_uri
        if resource_uuid is not None:
            self.resource_uuid = resource_uuid
        if result_limit is not None:
            self.result_limit = result_limit
        if target_uom is not None:
            self.target_uom = target_uom
        self.to = to

    @property
    def _from(self):
        """Gets the _from of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501

        The UNIX timestamp of the start date for filtering  # noqa: E501

        :return: The _from of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: int
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.

        The UNIX timestamp of the start date for filtering  # noqa: E501

        :param _from: The _from of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: int
        """
        if _from is None:
            raise ValueError("Invalid value for `_from`, must not be `None`")  # noqa: E501

        self.__from = _from

    @property
    def granularity(self):
        """Gets the granularity of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501

        The time granularity for the Resource data  # noqa: E501

        :return: The granularity of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """Sets the granularity of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.

        The time granularity for the Resource data  # noqa: E501

        :param granularity: The granularity of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: str
        """
        if granularity is None:
            raise ValueError("Invalid value for `granularity`, must not be `None`")  # noqa: E501
        allowed_values = ["5min", "hour", "day", "month"]  # noqa: E501
        if granularity not in allowed_values:
            raise ValueError(
                "Invalid value for `granularity` ({0}), must be one of {1}"  # noqa: E501
                .format(granularity, allowed_values)
            )

        self._granularity = granularity

    @property
    def resource_uri(self):
        """Gets the resource_uri of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501

        The Resource uniform resource identifier  # noqa: E501

        :return: The resource_uri of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._resource_uri

    @resource_uri.setter
    def resource_uri(self, resource_uri):
        """Sets the resource_uri of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.

        The Resource uniform resource identifier  # noqa: E501

        :param resource_uri: The resource_uri of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: str
        """

        self._resource_uri = resource_uri

    @property
    def resource_uuid(self):
        """Gets the resource_uuid of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501

        The Resource unique identifier  # noqa: E501

        :return: The resource_uuid of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._resource_uuid

    @resource_uuid.setter
    def resource_uuid(self, resource_uuid):
        """Sets the resource_uuid of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.

        The Resource unique identifier  # noqa: E501

        :param resource_uuid: The resource_uuid of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: str
        """

        self._resource_uuid = resource_uuid

    @property
    def result_limit(self):
        """Gets the result_limit of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501

        The limit of returned results  # noqa: E501

        :return: The result_limit of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: int
        """
        return self._result_limit

    @result_limit.setter
    def result_limit(self, result_limit):
        """Sets the result_limit of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.

        The limit of returned results  # noqa: E501

        :param result_limit: The result_limit of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: int
        """

        self._result_limit = result_limit

    @property
    def target_uom(self):
        """Gets the target_uom of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501


        :return: The target_uom of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: str
        """
        return self._target_uom

    @target_uom.setter
    def target_uom(self, target_uom):
        """Sets the target_uom of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.


        :param target_uom: The target_uom of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: str
        """

        self._target_uom = target_uom

    @property
    def to(self):
        """Gets the to of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501

        The UNIX timestamp of the end date for filtering  # noqa: E501

        :return: The to of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :rtype: int
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.

        The UNIX timestamp of the end date for filtering  # noqa: E501

        :param to: The to of this ResourceQueryCriteriaRequestWithinATimeframeAPIModel.  # noqa: E501
        :type: int
        """
        if to is None:
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResourceQueryCriteriaRequestWithinATimeframeAPIModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResourceQueryCriteriaRequestWithinATimeframeAPIModel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import sparkworks_client
from sparkworks_client.api.resource_api_api import ResourceAPIApi  # noqa: E501
from sparkworks_client.rest import ApiException


class TestResourceAPIApi(unittest.TestCase):
    """ResourceAPIApi unit test stubs"""

    def setUp(self):
        self.api = sparkworks_client.api.resource_api_api.ResourceAPIApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_count_resourmvnces(self):
        """Test case for count_resourmvnces

        Count Resources  # noqa: E501
        """
        pass

    def test_create_resource(self):
        """Test case for create_resource

        Create a new Resource  # noqa: E501
        """
        pass

    def test_delete_resource(self):
        """Test case for delete_resource

        Delete Resource by its UUID  # noqa: E501
        """
        pass

    def test_move_resource(self):
        """Test case for move_resource

        Move Resource by its UUID  # noqa: E501
        """
        pass

    def test_query_resources(self):
        """Test case for query_resources

        Retrieve a Resource by a query  # noqa: E501
        """
        pass

    def test_retrieve_resource(self):
        """Test case for retrieve_resource

        Retrieve a Spark Works Resource by its UUID  # noqa: E501
        """
        pass

    def test_retrieve_resources(self):
        """Test case for retrieve_resources

        Retrieve a collection of Resources  # noqa: E501
        """
        pass

    def test_update_resource(self):
        """Test case for update_resource

        Update Resource  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from sparkworks_client.api_client import ApiClient


class ResourceAPIApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def count_resources(self, **kwargs):  # noqa: E501
        """Count Resources  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the number of Resources that has permissions on. An administrator is able to retrieve the number of all Resources.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.count_resourmvnces_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.count_resourmvnces_with_http_info(**kwargs)  # noqa: E501
            return data

    def count_resourmvnces_with_http_info(self, **kwargs):  # noqa: E501
        """Count Resources  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve the number of Resources that has permissions on. An administrator is able to retrieve the number of all Resources.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.count_resourmvnces_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method count_resourmvnces" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/count', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_resource(self, resource_create_dto, **kwargs):  # noqa: E501
        """Create a new Resource  # noqa: E501

        A Spark Works authenticated user is able to request a new Resource creation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_resource(resource_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourceCreateDTO resource_create_dto: Resource Creation API Model (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_resource_with_http_info(resource_create_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.create_resource_with_http_info(resource_create_dto, **kwargs)  # noqa: E501
            return data

    def create_resource_with_http_info(self, resource_create_dto, **kwargs):  # noqa: E501
        """Create a new Resource  # noqa: E501

        A Spark Works authenticated user is able to request a new Resource creation  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_resource_with_http_info(resource_create_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourceCreateDTO resource_create_dto: Resource Creation API Model (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource_create_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'resource_create_dto' is set
        if ('resource_create_dto' not in params or
                params['resource_create_dto'] is None):
            raise ValueError("Missing the required parameter `resource_create_dto` when calling `create_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'resource_create_dto' in params:
            body_params = params['resource_create_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_resource(self, uuid, **kwargs):  # noqa: E501
        """Delete Resource by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to remove a Spark Works Resource that has permissions on by its unique identifier. An administrator is able to remove any Resource of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_resource(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Resource UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_resource_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_resource_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def delete_resource_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Delete Resource by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to remove a Spark Works Resource that has permissions on by its unique identifier. An administrator is able to remove any Resource of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_resource_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Resource UUID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `delete_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def move_resource(self, uuid, target_uuid, **kwargs):  # noqa: E501
        """Move Resource by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to move a Spark Works Resource that has permissions on by its unique identifierto a Spark Works Group that has permissions on. An administrator is able to move any Resource of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_resource(uuid, target_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Resource UUID (required)
        :param str target_uuid: The Group UUID (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.move_resource_with_http_info(uuid, target_uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.move_resource_with_http_info(uuid, target_uuid, **kwargs)  # noqa: E501
            return data

    def move_resource_with_http_info(self, uuid, target_uuid, **kwargs):  # noqa: E501
        """Move Resource by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to move a Spark Works Resource that has permissions on by its unique identifierto a Spark Works Group that has permissions on. An administrator is able to move any Resource of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.move_resource_with_http_info(uuid, target_uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Resource UUID (required)
        :param str target_uuid: The Group UUID (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'target_uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method move_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `move_resource`")  # noqa: E501
        # verify the required parameter 'target_uuid' is set
        if ('target_uuid' not in params or
                params['target_uuid'] is None):
            raise ValueError("Missing the required parameter `target_uuid` when calling `move_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501
        if 'target_uuid' in params:
            path_params['targetUUID'] = params['target_uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}/move/{targetUUID}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def query_resources(self, resource_query_dto, **kwargs):  # noqa: E501
        """Retrieve a Resource by a query  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Resource that has permissions on by a query object. An administrator is able to get any Resource by a query object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_resources(resource_query_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourceQueryDTO resource_query_dto: The Resource Query (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.query_resources_with_http_info(resource_query_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.query_resources_with_http_info(resource_query_dto, **kwargs)  # noqa: E501
            return data

    def query_resources_with_http_info(self, resource_query_dto, **kwargs):  # noqa: E501
        """Retrieve a Resource by a query  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Resource that has permissions on by a query object. An administrator is able to get any Resource by a query object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.query_resources_with_http_info(resource_query_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param ResourceQueryDTO resource_query_dto: The Resource Query (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['resource_query_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method query_resources" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'resource_query_dto' is set
        if ('resource_query_dto' not in params or
                params['resource_query_dto'] is None):
            raise ValueError("Missing the required parameter `resource_query_dto` when calling `query_resources`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'resource_query_dto' in params:
            body_params = params['resource_query_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_resource(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Spark Works Resource by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Resource, that has permissions on, by its UUID. An administrator is able to retrieve any Resource of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_resource(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Resource UUID (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_resource_with_http_info(uuid, **kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_resource_with_http_info(uuid, **kwargs)  # noqa: E501
            return data

    def retrieve_resource_with_http_info(self, uuid, **kwargs):  # noqa: E501
        """Retrieve a Spark Works Resource by its UUID  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve a Resource, that has permissions on, by its UUID. An administrator is able to retrieve any Resource of the platform  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_resource_with_http_info(uuid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Resource UUID (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `retrieve_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def retrieve_resources(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Resources  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform resources that the user has permissions on. An administrator is able to query all of the platform resources  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_resources(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[ResourceDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.retrieve_resources_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.retrieve_resources_with_http_info(**kwargs)  # noqa: E501
            return data

    def retrieve_resources_with_http_info(self, **kwargs):  # noqa: E501
        """Retrieve a collection of Resources  # noqa: E501

        A Spark Works Accounts authenticated common user is able to retrieve all of the Platform resources that the user has permissions on. An administrator is able to query all of the platform resources  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.retrieve_resources_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[ResourceDTO]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method retrieve_resources" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ResourceDTO]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_resource(self, uuid, resource_update_dto, **kwargs):  # noqa: E501
        """Update Resource  # noqa: E501

        A Spark Works Accounts authenticated common user is able to update a Resource's values that has permission on. An administrator is able to update the values of any Resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_resource(uuid, resource_update_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :param ResourceUpdateDTO resource_update_dto: resourceUpdateDTO (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_resource_with_http_info(uuid, resource_update_dto, **kwargs)  # noqa: E501
        else:
            (data) = self.update_resource_with_http_info(uuid, resource_update_dto, **kwargs)  # noqa: E501
            return data

    def update_resource_with_http_info(self, uuid, resource_update_dto, **kwargs):  # noqa: E501
        """Update Resource  # noqa: E501

        A Spark Works Accounts authenticated common user is able to update a Resource's values that has permission on. An administrator is able to update the values of any Resource.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_resource_with_http_info(uuid, resource_update_dto, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str uuid: The Group UUID (required)
        :param ResourceUpdateDTO resource_update_dto: resourceUpdateDTO (required)
        :return: ResourceDTO
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['uuid', 'resource_update_dto']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_resource" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'uuid' is set
        if ('uuid' not in params or
                params['uuid'] is None):
            raise ValueError("Missing the required parameter `uuid` when calling `update_resource`")  # noqa: E501
        # verify the required parameter 'resource_update_dto' is set
        if ('resource_update_dto' not in params or
                params['resource_update_dto'] is None):
            raise ValueError("Missing the required parameter `resource_update_dto` when calling `update_resource`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'uuid' in params:
            path_params['uuid'] = params['uuid']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'resource_update_dto' in params:
            body_params = params['resource_update_dto']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['oauth2']  # noqa: E501

        return self.api_client.call_api(
            '/v2/resource/{uuid}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ResourceDTO',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    SparkWorks Core API

    Management Service for the SparkWorks Processing Engine  # noqa: E501

    OpenAPI spec version: v2.0
    Contact: info@sparkworks.net
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class GroupDTO(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_by': 'str',
        'created_date': 'datetime',
        'deleted': 'bool',
        'last_modified_by': 'str',
        'last_modified_date': 'datetime',
        'name': 'str',
        'parent_path': 'str',
        'path': 'str',
        'uuid': 'str'
    }

    attribute_map = {
        'created_by': 'createdBy',
        'created_date': 'createdDate',
        'deleted': 'deleted',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_date': 'lastModifiedDate',
        'name': 'name',
        'parent_path': 'parentPath',
        'path': 'path',
        'uuid': 'uuid'
    }

    def __init__(self, created_by=None, created_date=None, deleted=None, last_modified_by=None, last_modified_date=None, name=None, parent_path=None, path=None, uuid=None):  # noqa: E501
        """GroupDTO - a model defined in Swagger"""  # noqa: E501

        self._created_by = None
        self._created_date = None
        self._deleted = None
        self._last_modified_by = None
        self._last_modified_date = None
        self._name = None
        self._parent_path = None
        self._path = None
        self._uuid = None
        self.discriminator = None

        if created_by is not None:
            self.created_by = created_by
        if created_date is not None:
            self.created_date = created_date
        if deleted is not None:
            self.deleted = deleted
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_date is not None:
            self.last_modified_date = last_modified_date
        if name is not None:
            self.name = name
        if parent_path is not None:
            self.parent_path = parent_path
        if path is not None:
            self.path = path
        if uuid is not None:
            self.uuid = uuid

    @property
    def created_by(self):
        """Gets the created_by of this GroupDTO.  # noqa: E501


        :return: The created_by of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this GroupDTO.


        :param created_by: The created_by of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def created_date(self):
        """Gets the created_date of this GroupDTO.  # noqa: E501


        :return: The created_date of this GroupDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this GroupDTO.


        :param created_date: The created_date of this GroupDTO.  # noqa: E501
        :type: datetime
        """

        self._created_date = created_date

    @property
    def deleted(self):
        """Gets the deleted of this GroupDTO.  # noqa: E501


        :return: The deleted of this GroupDTO.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this GroupDTO.


        :param deleted: The deleted of this GroupDTO.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this GroupDTO.  # noqa: E501


        :return: The last_modified_by of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this GroupDTO.


        :param last_modified_by: The last_modified_by of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_date(self):
        """Gets the last_modified_date of this GroupDTO.  # noqa: E501


        :return: The last_modified_date of this GroupDTO.  # noqa: E501
        :rtype: datetime
        """
        return self._last_modified_date

    @last_modified_date.setter
    def last_modified_date(self, last_modified_date):
        """Sets the last_modified_date of this GroupDTO.


        :param last_modified_date: The last_modified_date of this GroupDTO.  # noqa: E501
        :type: datetime
        """

        self._last_modified_date = last_modified_date

    @property
    def name(self):
        """Gets the name of this GroupDTO.  # noqa: E501


        :return: The name of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GroupDTO.


        :param name: The name of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def parent_path(self):
        """Gets the parent_path of this GroupDTO.  # noqa: E501


        :return: The parent_path of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._parent_path

    @parent_path.setter
    def parent_path(self, parent_path):
        """Sets the parent_path of this GroupDTO.


        :param parent_path: The parent_path of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._parent_path = parent_path

    @property
    def path(self):
        """Gets the path of this GroupDTO.  # noqa: E501


        :return: The path of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this GroupDTO.


        :param path: The path of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._path = path

    @property
    def uuid(self):
        """Gets the uuid of this GroupDTO.  # noqa: E501


        :return: The uuid of this GroupDTO.  # noqa: E501
        :rtype: str
        """
        return self._uuid

    @uuid.setter
    def uuid(self, uuid):
        """Sets the uuid of this GroupDTO.


        :param uuid: The uuid of this GroupDTO.  # noqa: E501
        :type: str
        """

        self._uuid = uuid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GroupDTO, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GroupDTO):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
